containertools.delete_contents_of_container_starting_at_or_after_prolated_offset
================================================================================

.. autofunction:: abjad.tools.containertools.delete_contents_of_container_starting_at_or_after_prolated_offset
